pub trait JoinStrsExt: Sized
{
    /// Join an iterator of `str` with a seperator
    fn join(self, with: &str) -> String;
}

impl<T,I> JoinStrsExt for I
where I: Iterator<Item=T>,
      T: AsRef<str>
{
    fn join(self, with: &str) -> String
    {
	let mut output = String::new();
	let mut first=true;
	for string in self
	{
	    if !first {
		output.push_str(with);
	    }
	    let string = string.as_ref();
	    output.push_str(string);
	    first=false;
	}
	output
    }
}

/// Explicit utilities
pub mod util {
    use crate::*;
    use std::os::fd::*;

    /// Check if `stream` is open to a tty.
    pub fn is_terminal<T: ?Sized + AsFd>(stream: &T) -> bool
    {
	use std::ffi::c_int;
	unsafe extern "C" {
	    safe fn isatty(fd: c_int) -> c_int;
	}

	isatty(stream.as_fd().as_raw_fd()) == 1
    }
}
